Function fasten_combine::combine_error_vectors[][src]

pub(crate) fn combine_error_vectors(
    errors1: &Vec<f32>,
    errors2: &Vec<f32>
) -> Vec<f32>
Notable traits for Vec<u8, A>
impl<A> Write for Vec<u8, A> where
    A: Allocator
Combines vectors of error probabilities such that the rate of error is probability of error from vector one times the probability of error from vector two.