Function fasten_combine::combine_error_vectors [−][src]
Combines vectors of error probabilities such that the rate of error is probability of error from vector one times the probability of error from vector two.